Enum logix_type::error::Wanted
source · pub enum Wanted {
}Variants
Token(Token<'static>)
Tokens(&'static [Token<'static>])
LitStr
FullPath
RelPath
ExecutablePath
NameOnlyPath
ValidPath
LitNum(&'static str)
Ident
ItemOrEnd
ItemDelim
Item
ItemUnknown
An error occured while parsing a delimited list of items, but not able to determine what was expected