The LogixType trait and types used to describe the types
Structs
- Logix
Type Descriptor - Describes a type in the logix config file
- Value
- Represents a value and the location in the config file
Enums
- Logix
Value Descriptor - Describes a type