Module types

Module types 

Types that implement the LogixType trait

Structs

ExecutableEnv
The environment used when resolving executable paths
ExecutablePath
A path to an executable. This is either a full path, or a filename. If it is a relative path it will fail to avoid issues. For example, imagine what happens if EDITOR is set to a relative path.
FullPath
Represents a validated full path
NameOnlyPath
Represents a validated file or directory name without any path components
RelPath
Represents a validated relative path
ShortStr
Represents a short string, will not need allocation for typical identifiers

Enums

Data
ValidPath
Represents a validated full path

Type Aliases

Map