Module logix_type::type_trait

source ·
The LogixType trait and types used to describe the types

Structs

Enums

Traits

  • This trait is used to represent types that can be stored in a logix config.