Module logix_type::type_trait
source · Expand description
The LogixType trait and types used to describe the types
Structs
- Describes a type in the logix config file
- Represents a value and the location in the config file
Enums
- Describes a type
Traits
- This trait is used to represent types that can be stored in a logix config.