pub trait LogixType: Sized {
// Required methods
fn descriptor() -> &'static LogixTypeDescriptor;
fn default_value() -> Option<Self>;
fn logix_parse<FS: LogixVfs>(
p: &mut LogixParser<'_, '_, FS>,
) -> Result<Value<Self>>;
}Expand description
This trait is used to represent types that can be stored in a logix config.
Required Methods
Sourcefn descriptor() -> &'static LogixTypeDescriptor
fn descriptor() -> &'static LogixTypeDescriptor
A description of the type, intended used for documentation and auto-completion
Sourcefn default_value() -> Option<Self>
fn default_value() -> Option<Self>
If the value is optional, this returns Some
Sourcefn logix_parse<FS: LogixVfs>(
p: &mut LogixParser<'_, '_, FS>,
) -> Result<Value<Self>>
fn logix_parse<FS: LogixVfs>( p: &mut LogixParser<'_, '_, FS>, ) -> Result<Value<Self>>
Parse the value from the given parser state
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.