Trait logix_type::type_trait::LogixType
source · pub trait LogixType: Sized {
// Required methods
fn descriptor() -> &'static LogixTypeDescriptor;
fn default_value() -> Option<Self>;
fn logix_parse<FS: LogixVfs>(
p: &mut LogixParser<'_, '_, FS>
) -> Result<Value<Self>>;
}Expand description
This trait is used to represent types that can be stored in a logix config.
Required Methods
sourcefn descriptor() -> &'static LogixTypeDescriptor
fn descriptor() -> &'static LogixTypeDescriptor
A description of the type, intended used for documentation and auto-completion
sourcefn default_value() -> Option<Self>
fn default_value() -> Option<Self>
If the value is optional, this returns Some
sourcefn logix_parse<FS: LogixVfs>(
p: &mut LogixParser<'_, '_, FS>
) -> Result<Value<Self>>
fn logix_parse<FS: LogixVfs>( p: &mut LogixParser<'_, '_, FS> ) -> Result<Value<Self>>
Parse the value from the given parser state
Object Safety
This trait is not object safe.