Module logix_type::types

source ·
Types that implement the LogixType trait

Structs

  • The environment used when resolving executable paths
  • A path to an executable. This is either a full path, or a filename. If it is a relative path it will fail to avoid issues. For example, imagine what happens if EDITOR is set to a relative path.
  • Represents a validated full path
  • Represents a validated file or directory name without any path components
  • Represents a validated relative path
  • Represents a short string, will not need allocation for typical identifiers

Enums

Type Aliases