Module logix_type::types

source ·

Structs

  • A path to an executable. This is either a full path, or a filename. If it is a relative path it will fail to avoid issues. For example, imagine what happens if EDITOR is set to a relative path.
  • Represents a validated full path
  • Represents a validated file or directory name without any path components
  • Represents a validated relative path

Enums